==> ejc-procurement-impl-3.0.0-20251202.031021-3-sources.jar: com/ejianc/business/procurement/bean/CatalogItemEntity.java <==
package com.ejianc.business.procurement.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

/**
 * 一级集采目录-明细
 * 
 * @author generator
 * 
 */
 @TableName("ejc_procurement_catalog_items")
public class CatalogItemEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="code")
    private String code; // 编码
    @TableField(value="name")
    private String name; // 名称
    @TableField(value="description")
    private String description; // 描述
    @TableField(value="sequence")
    private Integer sequence; // 排序
    @TableField(value="enabled")
    private Integer enabled; // 1:启用、0:停用
    @TableField(value="category_id")
    private Long categoryId; // 分类
    
    
    

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }
    public Integer getSequence() {
        return sequence;
    }

    public void setSequence(Integer sequence) {
        this.sequence = sequence;
    }
    public Integer getEnabled() {
        return enabled;
    }

    public void setEnabled(Integer enabled) {
        this.enabled = enabled;
    }
    public Long getCategoryId() {
        return categoryId;
    }

    public void setCategoryId(Long categoryId) {
        this.categoryId = categoryId;
    }
    
}

==> ejc-procurement-impl-3.0.0-20251202.073935-6-sources.jar: com/ejianc/business/procurement/bean/CatalogItemEntity.java <==
package com.ejianc.business.procurement.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

/**
 * 一级集采目录-明细
 * 
 * @author generator
 * 
 */
 @TableName("ejc_procurement_catalog_items")
public class CatalogItemEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="code")
    private String code; // 编码
    @TableField(value="name")
    private String name; // 名称
    @TableField(value="description")
    private String description; // 描述
    @TableField(value="sequence")
    private Integer sequence; // 排序
    @TableField(value="enabled")
    private Integer enabled; // 1:启用、0:停用
    @TableField(value="category_id")
    private Long categoryId; // 分类
    @TableField(value="business_type")
    private String businessType; // 业务类别1-工程，2-货物，3-服务


    public String getBusinessType() {
        return businessType;
    }

    public void setBusinessType(String businessType) {
        this.businessType = businessType;
    }

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }
    public Integer getSequence() {
        return sequence;
    }

    public void setSequence(Integer sequence) {
        this.sequence = sequence;
    }
    public Integer getEnabled() {
        return enabled;
    }

    public void setEnabled(Integer enabled) {
        this.enabled = enabled;
    }
    public Long getCategoryId() {
        return categoryId;
    }

    public void setCategoryId(Long categoryId) {
        this.categoryId = categoryId;
    }
    
}
